import { aws_iam as iam, aws_imagebuilder as imagebuilder } from 'aws-cdk-lib';
import { Construct } from 'constructs';
export interface ImagePipelineProps {
    /**
     * Relative path to Image Builder component documents
     */
    readonly componentDocuments: string[];
    /**
     * Names of the Component Documents
     */
    readonly componentNames: string[];
    /**
     * Versions for each component document
     */
    readonly componentVersions: string[];
    /**
     * Name of the instance profile that will be associated with the Instance Configuration.
     */
    readonly profileName: string;
    /**
     * Additional policies to add to the instance profile associated with the Instance Configurations
     */
    readonly additionalPolicies?: iam.ManagedPolicy[];
    /**
     * Name of the Infrastructure Configuration for Image Builder
     */
    readonly infraConfigName: string;
    /**
     * Name of the Image Recipe
     */
    readonly imageRecipe: string;
    /**
     * UserData script that will override default one (if specified)
     *
     * @default - none
     */
    readonly userDataScript?: string;
    /**
     * Image recipe version (Default: 0.0.1)
     */
    readonly imageRecipeVersion?: string;
    /**
     * Name of the Image Pipeline
     */
    readonly pipelineName: string;
    /**
     * The source (parent) image that the image recipe uses as its base environment. The value can be the parent image ARN or an Image Builder AMI ID
     */
    readonly parentImage: string;
    /**
     * KMS Key used to encrypt the SNS topic. Enter an existing KMS Key Alias in your target account/region.
     */
    readonly kmsKeyAlias: string;
    /**
     * List of instance types used in the Instance Configuration (Default: [ 't3.medium', 'm5.large', 'm5.xlarge' ])
     */
    readonly instanceTypes?: string[];
    /**
     * Platform type Linux or Windows (Default: Linux)
     */
    readonly platform?: string;
    /**
    * Email used to receive Image Builder Pipeline Notifications via SNS
    */
    readonly email?: string;
    /**
     * List of security group IDs for the Infrastructure Configuration
     */
    readonly securityGroups?: string[];
    /**
     * Subnet ID for the Infrastructure Configuration
     */
    readonly subnetId?: string;
    /**
     * Configuration for the AMI's EBS volume
     */
    readonly ebsVolumeConfiguration?: imagebuilder.CfnImageRecipe.EbsInstanceBlockDeviceSpecificationProperty;
}
export declare class ImagePipeline extends Construct {
    imageRecipeComponents: imagebuilder.CfnImageRecipe.ComponentConfigurationProperty[];
    constructor(scope: Construct, id: string, props: ImagePipelineProps);
}
